;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "diff-ansi" "20251216.227"
  "Display diffs using alternative diffing tools."
  '((emacs "29.1"))
  :url "https://codeberg.org/ideasman42/emacs-diff-ansi"
  :commit "dd600ebdc632c8f525dcba392526e6e56fcbca61"
  :revdesc "dd600ebdc632"
  :authors '(("Campbell Barton" . "ideasman42@gmail.com"))
  :maintainers '(("Campbell Barton" . "ideasman42@gmail.com")))
